import { t } from '@traversable/schema-core';
const RAW = {
    any: { type: 'object', properties: {}, nullable: true },
    null: { type: 'null', enum: [null] },
    boolean: { type: 'boolean' },
    integer: { type: 'integer' },
    number: { type: 'number' },
    string: { type: 'string' },
};
const JsonSchema_any = t.object({ type: t.eq('object'), properties: t.object({}), nullable: t.eq(true) });
const JsonSchema_null = t.object({ type: t.eq('null'), enum: t.tuple(t.eq(null)) });
const JsonSchema_boolean = t.object({ type: t.eq('boolean') });
const JsonSchema_integer = t.object({ type: t.eq('integer') });
const JsonSchema_number = t.object({ type: t.eq('number') });
const JsonSchema_string = t.object({ type: t.eq('string') });
const JsonSchema_const = t.object({ const: t.unknown });
const JsonSchema_enum = t.object({ enum: t.array(t.unknown, 'readonly') });
const JsonSchema_array = t.object({ type: t.eq('array'), items: t.unknown });
const JsonSchema_record_ = t.object({
    type: t.eq('object'),
    additionalProperties: t.unknown,
});
const JsonSchema_record = (u) => JsonSchema_record_(u);
const JsonSchema_union_ = t.object({ anyOf: t.array(t.unknown, 'readonly') });
const JsonSchema_union = t.inline((u) => JsonSchema_union_(u));
const JsonSchema_intersect_ = t.object({ allOf: t.array(t.unknown, 'readonly') });
const JsonSchema_intersect = t.inline((u) => JsonSchema_intersect_(u));
const JsonSchema_object = t.object({
    type: t.eq('object'),
    required: t.array(t.string),
    properties: t.unknown,
});
const JsonSchema_tuple = t.object({
    type: t.eq('array'),
    items: t.unknown,
    minItems: t.number,
    maxItems: t.number,
    additionalItems: t.eq(false),
});
const Nullary = t.union(JsonSchema_any, JsonSchema_null, JsonSchema_boolean, JsonSchema_integer, JsonSchema_number, JsonSchema_string);
const Special = t.union(JsonSchema_enum, JsonSchema_const);
const Unary = t.union(JsonSchema_array, JsonSchema_record, JsonSchema_union, JsonSchema_intersect, JsonSchema_tuple, JsonSchema_object);
export var JsonSchema;
(function (JsonSchema) {
    JsonSchema.raw = RAW;
})(JsonSchema || (JsonSchema = {}));
export const any = JsonSchema_any;
/* data types */
JsonSchema.null = JsonSchema_null;
JsonSchema.boolean = JsonSchema_boolean;
JsonSchema.integer = JsonSchema_integer;
JsonSchema.number = JsonSchema_number;
JsonSchema.string = JsonSchema_string;
JsonSchema.any = JsonSchema_any;
JsonSchema.enum = JsonSchema_enum;
JsonSchema.const = JsonSchema_const;
JsonSchema.array = JsonSchema_array;
JsonSchema.record = JsonSchema_record;
JsonSchema.union = JsonSchema_union;
JsonSchema.intersect = JsonSchema_intersect;
JsonSchema.tuple = JsonSchema_tuple;
JsonSchema.object = JsonSchema_object;
/* terms */
JsonSchema.Nullary = Nullary;
JsonSchema.Unary = Unary;
JsonSchema.Special = Special;
//# sourceMappingURL=specification.js.map